@@ -275,26 +275,38 @@ gossip_account_manager_find (GossipAccountManager *manager,
 
 GossipAccount *
 gossip_account_manager_find_by_id (GossipAccountManager *manager,
-				   const gchar          *id)
+				   const gchar          *id,
+				   const gchar          *type_str)
 {
 	GossipAccountManagerPriv *priv;
 	GList                    *l;
 
 	g_return_val_if_fail (GOSSIP_IS_ACCOUNT_MANAGER (manager), NULL);
-	g_return_val_if_fail (id != NULL, NULL);
+	g_return_val_if_fail (id != NULL || type_str != NULL, NULL);
 
 	priv = GET_PRIV (manager);
 
 	for (l = priv->accounts; l; l = l->next) {
-		GossipAccount *account;
-		const gchar   *account_id;
+		GossipAccount     *account;
+		GossipAccountType  account_type;
+		const gchar       *account_id;
+		const gchar       *account_type_str;
 
 		account = l->data;
-		gossip_account_param_get (account, "id", &account_id, NULL);
 
-		if (strcmp (account_id, id) == 0) {
-			return account;
+		account_id = gossip_account_get_id (account);
+		account_type = gossip_account_get_type (account);
+		account_type_str = gossip_account_type_to_string (account_type);
+
+		if (id && account_id && strcmp (id, account_id) != 0) {
+			continue;
 		}
+
+		if (type_str && account_type_str && strcmp (type_str, account_type_str) != 0) {
+			continue;
+		}
+
+		return account;
 	}
 
 	return NULL;
@@ -478,6 +490,9 @@ account_manager_parse_account (GossipAccountManager *manager,
 		if (strcmp (tag, "name") == 0) {
 			gossip_account_set_name (account, str);
 		}
+		else if (strcmp (tag, "id") == 0) {
+			gossip_account_set_id (account, str);
+		}
 		else if (strcmp (tag, "auto_connect") == 0) {
 			gossip_account_set_auto_connect (account, strcmp (str, "yes") == 0);
 		}
@@ -502,9 +517,17 @@ account_manager_parse_account (GossipAccountManager *manager,
 			type = gossip_dbus_type_to_g_type (type_str);
 			g_value = gossip_string_to_g_value (str, type);
 
-			gossip_account_param_set_g_value (account,
-							  param_name,
-							  g_value);
+			/* Compatibility: The ID was defined here
+			 * in old accounts.xml files. */
+			if (strcmp (param_name, "id") != 0) {
+				gossip_account_param_set_g_value (account,
+								  param_name,
+								  g_value);			
+			} else {
+				/* Save in the new format */
+				need_saving = TRUE;
+				gossip_account_set_id (account, str);
+			}
 
 			g_value_unset (g_value);
 			g_free (g_value);
@@ -512,9 +535,6 @@ account_manager_parse_account (GossipAccountManager *manager,
 			xmlFree (type_str);
 		}
 		/* Those are deprecated and kept for compatibility only */
-		else if (strcmp (tag, "id") == 0) {
-			gossip_account_param_set (account, "id", str, NULL);
-		}
 		else if (strcmp (tag, "resource") == 0) {
 			gossip_account_param_set (account, "resource", str, NULL);
 		}
@@ -547,7 +567,7 @@ account_manager_parse_account (GossipAccountManager *manager,
 	const gchar *resource_found = NULL;
 	const gchar *id;
 
-	gossip_account_param_get (account, "id", &id, NULL);
+	id = gossip_account_get_id (account);
 	str = g_strdup (id);
 	if (str) {
 		/* FIXME: This hack is so we don't get bug
@@ -567,8 +587,8 @@ account_manager_parse_account (GossipAccountManager *manager,
 	}
 
 	if (resource_found) {
+		gossip_account_set_id (account, str);
 		gossip_account_param_set (account,
-					  "id", str,
 					  "resource", resource_found,
 					  NULL);
 		need_saving = TRUE;
@@ -708,6 +728,9 @@ account_manager_file_save (GossipAccountManager *manager)
 		node = xmlNewChild (root, NULL, "account", NULL);
 		xmlNewProp (node, "type", type);
 		xmlNewTextChild (node, NULL, "name", gossip_account_get_name (account));
+		if (gossip_account_get_id (account)) {
+			xmlNewTextChild (node, NULL, "id", gossip_account_get_id (account));
+		}
 		xmlNewTextChild (node, NULL, "auto_connect", gossip_account_get_auto_connect (account) ? "yes" : "no");
 		xmlNewTextChild (node, NULL, "use_proxy", gossip_account_get_use_proxy (account) ? "yes" : "no");
 
