@@ -26,6 +26,8 @@
 
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
 #define GOSSIP_TYPE_ACCOUNT         (gossip_account_get_gtype ())
 #define GOSSIP_ACCOUNT(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GOSSIP_TYPE_ACCOUNT, GossipAccount))
 #define GOSSIP_ACCOUNT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), GOSSIP_TYPE_ACCOUNT, GossipAccountClass))
@@ -75,6 +77,10 @@ GType             gossip_account_get_gtype         (void) G_GNUC_CONST;
 void              gossip_account_param_new         (GossipAccount           *account,
 						    const gchar             *first_param_name,
 						    ...);
+void              gossip_account_param_new_g_value (GossipAccount           *account,
+						    const gchar             *param_name,
+						    const GValue            *g_value,
+						    GossipAccountParamFlags  flags);
 void              gossip_account_param_set         (GossipAccount           *account,
 						    const gchar             *first_param_name,
 						    ...);
@@ -92,9 +98,12 @@ void              gossip_account_param_foreach     (GossipAccount           *acc
 						    GossipAccountParamFunc   callback,
 						    gpointer                 user_data);
 GossipAccountType gossip_account_get_type          (GossipAccount           *account);
+const gchar *     gossip_account_get_id            (GossipAccount           *account);
 const gchar *     gossip_account_get_name          (GossipAccount           *account);
 gboolean          gossip_account_get_auto_connect  (GossipAccount           *account);
 gboolean          gossip_account_get_use_proxy     (GossipAccount           *account);
+void              gossip_account_set_id            (GossipAccount           *account,
+						    const gchar             *id);
 void              gossip_account_set_name          (GossipAccount           *account,
 						    const gchar             *name);
 void              gossip_account_set_auto_connect  (GossipAccount           *account,
@@ -107,4 +116,6 @@ gboolean          gossip_account_equal             (gconstpointer            v1,
 const gchar *     gossip_account_type_to_string    (GossipAccountType        type);
 GossipAccountType gossip_account_string_to_type    (const gchar             *str);
 
+G_END_DECLS
+
 #endif /* __GOSSIP_ACCOUNT_H__ */
