@@ -25,6 +25,8 @@
 #include <gtk/gtktreestore.h>
 #include <gtk/gtktreeselection.h>
 
+G_BEGIN_DECLS
+
 #define GOSSIP_TYPE_CHAT_WINDOW         (gossip_chat_window_get_type ())
 #define GOSSIP_CHAT_WINDOW(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GOSSIP_TYPE_CHAT_WINDOW, GossipChatWindow))
 #define GOSSIP_CHAT_WINDOW_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), GOSSIP_TYPE_CHAT_WINDOW, GossipChatWindowClass))
@@ -39,11 +41,11 @@ typedef struct _GossipChatWindowPriv  GossipChatWindowPriv;
 #include "gossip-chat.h"
 
 struct _GossipChatWindow {
-        GObject parent;
+	GObject parent;
 };
 
 struct _GossipChatWindowClass {
-        GObjectClass parent_class;
+	GObjectClass parent_class;
 };
 
 GType             gossip_chat_window_get_type        (void);
@@ -57,9 +59,14 @@ void              gossip_chat_window_add_chat        (GossipChatWindow *window,
 						      GossipChat       *chat);
 void              gossip_chat_window_remove_chat     (GossipChatWindow *window,
 						      GossipChat       *chat);
+void              gossip_chat_window_move_chat       (GossipChatWindow *old_window,
+						      GossipChatWindow *new_window,
+						      GossipChat       *chat);
 void              gossip_chat_window_switch_to_chat  (GossipChatWindow *window,
 						      GossipChat       *chat);
 
 gboolean          gossip_chat_window_has_focus       (GossipChatWindow *window);
 
+G_END_DECLS
+
 #endif /* __GOSSIP_CHAT_WINDOW_H__ */
