@@ -23,15 +23,19 @@
 
 #include <libgossip/gossip-session.h>
 
+G_BEGIN_DECLS
+
 typedef enum {
 	GOSSIP_SOUND_CHAT,
 	GOSSIP_SOUND_OFFLINE,
 	GOSSIP_SOUND_ONLINE
 } GossipSound;
 
-void gossip_sound_init   (GossipSession *session);
+void gossip_sound_init        (GossipSession *session);
+void gossip_sound_finalize    (void);
+void gossip_sound_play        (GossipSound sound);
+void gossip_sound_set_enabled (gboolean    enabled);
 
-void gossip_sound_play   (GossipSound sound);
-void gossip_sound_toggle (gboolean    enabled);
+G_END_DECLS
 
 #endif /* __GOSSIP_SOUND_H__ */
